pub(crate) fn parse_iterations() -> u32Expand description
Reads --iterations <n> from the process arguments, falling back to
DEFAULT_ITERATIONS when it is absent or not a positive integer.
pub(crate) fn parse_iterations() -> u32Reads --iterations <n> from the process arguments, falling back to
DEFAULT_ITERATIONS when it is absent or not a positive integer.