pub(crate) fn entry_for<'a>(
package: &'a Package,
program: &Program,
name: &str,
) -> Result<(&'a str, &'a str, Vec<String>), String>Expand description
The module, function name, and granted capabilities for [run.<name>],
looked up the way cove run looks up a run.